pub trait Args<T> {
// Required method
fn get(&self) -> T;
}Expand description
A “set of arguments” that contains T.
Required Methods
Sourcefn get(&self) -> T
fn get(&self) -> T
Get T from the set of arguments.
The signature of this method usually means that some copying/cloning has to happen. To see why it is designed like this, please refer to the crate-level documentation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".