pub trait Callable<A, T> {
type Output;
// Required method
fn call(self, args: A) -> Self::Output;
}Expand description
A trait to describe any kind of type that can be called.
This trait and the Args trait are the foundation of the crate. It
provides Callable::call which is how apply (and friends) work.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".